[cells-cvs] CVS cells/cells-test
ktilton
ktilton at common-lisp.net
Fri Jun 23 01:04:56 UTC 2006
Update of /project/cells/cvsroot/cells/cells-test
In directory clnet:/tmp/cvs-serv31550/cells-test
Modified Files:
df-interference.lisp hello-world.lisp test-synapse.lisp
test.lisp
Log Message:
New abbreviated defmodel: defmd
Starting to change internals names as the mood hits me.
--- /project/cells/cvsroot/cells/cells-test/hello-world.lisp 2006/06/20 14:16:45 1.4
+++ /project/cells/cvsroot/cells/cells-test/hello-world.lisp 2006/06/23 01:04:56 1.5
@@ -24,13 +24,14 @@
(in-package :cells)
+
(defmd computer ()
- (happen (c-in nil) :ephemeral)
+ (happen (c-in nil) :cell :ephemeral)
(location (c? (case (^happen)
(:leave :away)
(:arrive :at-home)
(t .cache)))) ;; ie, unchanged
- (response nil :ephemeral))
+ (response nil :cell :ephemeral))
(defobserver response(self new-response old-response)
(when new-response
--- /project/cells/cvsroot/cells/cells-test/test-synapse.lisp 2006/03/16 05:22:08 1.1
+++ /project/cells/cvsroot/cells/cells-test/test-synapse.lisp 2006/06/23 01:04:56 1.2
@@ -22,7 +22,6 @@
(in-package :cells)
-
(defmodel m-syn ()
((m-syn-a :initform nil :initarg :m-syn-a :accessor m-syn-a)
(m-syn-b :initform nil :initarg :m-syn-b :accessor m-syn-b)
--- /project/cells/cvsroot/cells/cells-test/test.lisp 2006/06/20 14:16:45 1.7
+++ /project/cells/cvsroot/cells/cells-test/test.lisp 2006/06/23 01:04:56 1.8
@@ -34,14 +34,14 @@
- make sure they fire when they should, and do not when they should not
-- make sure they survive an evaluation by the user which does not branch to
+- make sure they survive an evaluation by the caller which does not branch to
them (ie, does not access them)
- make sure they optimize away
- test with forms which access multiple other cells
-- look at direct alteration of a user
+- look at direct alteration of a caller
- does SETF honor not propagating, as well as a c-ruled after re-calcing
@@ -233,7 +233,7 @@
collect (cons sn c))))
(trc "dependencies of" self)
(loop for (sn . c) in slot-cells
- do (trc "slot" sn :users (mapcar 'c-slot-name (c-users c))))))
+ do (trc "slot" sn :callers (mapcar 'c-slot-name (c-callers c))))))
(def-cell-test m-worst-case
(let ((m (make-instance 'm-worst-case)))
More information about the Cells-cvs
mailing list
--- /project/cells/cvsroot/cells/cells-test/df-interference.lisp 2006/05/30 02:47:45 1.4
+++ /project/cells/cvsroot/cells/cells-test/df-interference.lisp 2006/06/23 01:04:56 1.5
@@ -64,7 +64,7 @@
;; - b depends on c
;;
;; if c changes, depending on the accident of the order in which a and b happened to
;; be first evaluated, a might appear before b on c's list of dependents (users). then the
;; following happens:
;;
;; - c triggers a
@@ -113,7 +113,7 @@
(trc "cell is" c)
(when (typep (cdr c) 'cell)
(print `(notifier ,c))
- (dolist (u (c-users (cdr c)))
+ (dolist (u (c-callers (cdr c)))
(print `(___ ,u)))))
))
@@ -64,7 +64,7 @@
;;
;; if c changes, depending on the accident of the order in which a and b happened to
-;; be first evaluated, a might appear before b on c's list of dependents (users). then the
+;; be first evaluated, a might appear before b on c's list of dependents (callers). then the
;; following happens:
;;